==> haskell-binary-tagged-0.1.5.1-14-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-binary-tagged.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: binary-tagged
version: 0.1.5.1
id: binary-tagged-0.1.5.1-BLKnw8plJn759fyYp1epvN
key: binary-tagged-0.1.5.1-BLKnw8plJn759fyYp1epvN
license: BSD-3-Clause
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
author: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/binary-tagged#readme
synopsis: Tagged binary serialisation.
description:
    Check <https://github.com/phadej/binary-tagged#readme README on Github>
category: Data
abi: 22b3a915fdb4bd681582219ea865c8fb
exposed: True
exposed-modules:
    Data.Binary.Tagged
import-dirs: /usr/lib/ghc-8.6.3/site-local/binary-tagged-0.1.5.1
library-dirs: /usr/lib/ghc-8.6.3/site-local/binary-tagged-0.1.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/binary-tagged-0.1.5.1
hs-libraries: HSbinary-tagged-0.1.5.1-BLKnw8plJn759fyYp1epvN
depends:
    SHA-1.6.4.4-1GMMHy6WdrlGpMrtGTWHUv
    aeson-1.4.2.0-G7R46TimzIMEAEOuM4Wcyu array-0.5.3.0 base-4.12.0.0
    base16-bytestring-0.1.1.6-17atVnUhDnM13pAkKbwL6I binary-0.8.6.0
    bytestring-0.10.8.2 containers-0.6.0.1
    generics-sop-0.4.0.1-50QtUhSPhiXGrcY9j3QNt9
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    scientific-0.3.6.2-9lkO4JSfZDD3N7SSlCrzCi
    tagged-0.8.6-FABECvKnqYbBCttH1EeJvB text-1.2.3.1 time-1.8.0.2
    unordered-containers-0.2.10.0-HO72tBDce9GHcBPxpae42I
    vector-0.12.0.2-5G85DK6NPIx1LphnqJy7eO
haddock-interfaces: /usr/share/doc/haskell-binary-tagged/html/binary-tagged.haddock
haddock-html: /usr/share/doc/haskell-binary-tagged/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-binary-tagged-0.1.5.1-15-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-binary-tagged.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: binary-tagged
version: 0.1.5.1
id: binary-tagged-0.1.5.1-5pCfECCC4WqJqoMVV3rneT
key: binary-tagged-0.1.5.1-5pCfECCC4WqJqoMVV3rneT
license: BSD-3-Clause
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
author: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/binary-tagged#readme
synopsis: Tagged binary serialisation.
description:
    Check <https://github.com/phadej/binary-tagged#readme README on Github>
category: Data
abi: e868bc9ab551855392b43fcf92a2afaf
exposed: True
exposed-modules:
    Data.Binary.Tagged
import-dirs: /usr/lib/ghc-8.6.3/site-local/binary-tagged-0.1.5.1
library-dirs: /usr/lib/ghc-8.6.3/site-local/binary-tagged-0.1.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/binary-tagged-0.1.5.1
hs-libraries: HSbinary-tagged-0.1.5.1-5pCfECCC4WqJqoMVV3rneT
depends:
    SHA-1.6.4.4-1GMMHy6WdrlGpMrtGTWHUv
    aeson-1.4.2.0-4owspgDf5bB3ddpBjmAUar array-0.5.3.0 base-4.12.0.0
    base16-bytestring-0.1.1.6-17atVnUhDnM13pAkKbwL6I binary-0.8.6.0
    bytestring-0.10.8.2 containers-0.6.0.1
    generics-sop-0.4.0.1-50QtUhSPhiXGrcY9j3QNt9
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    scientific-0.3.6.2-9lkO4JSfZDD3N7SSlCrzCi
    tagged-0.8.6-FABECvKnqYbBCttH1EeJvB text-1.2.3.1 time-1.8.0.2
    unordered-containers-0.2.10.0-6u5qZnIDidK2MmAyNc87rJ
    vector-0.12.0.2-5G85DK6NPIx1LphnqJy7eO
haddock-interfaces: /usr/share/doc/haskell-binary-tagged/html/binary-tagged.haddock
haddock-html: /usr/share/doc/haskell-binary-tagged/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
